/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */

import type { FastifyRequest } from "fastify";

/**
 * Parses an IP address from a request, first looking for the
 * Cloudflare headers, then falling back to the request IP.
 * @param request - The Fastify request object.
 * @returns The IP address as a string.
 */
export const getIpFromRequest = (request: FastifyRequest): string => {
  const header
    = request.headers["x-forwarded-for"] ?? request.headers["cf-connecting-ip"];
  if (typeof header === "string") {
    return header;
  }
  if (Array.isArray(header)) {
    return header[0] ?? header.join(", ");
  }
  return request.ip;
};
